# yib

`yib` is one Python utility library.

> Why "y"? That's because the Chinese character "一" (yī) means "one".

<p>
<a href="https://pypi.org/project/yib"><img alt="PyPI" src="https://img.shields.io/pypi/v/yib"></a>
<a href="https://pypi.org/project/yib"><img alt="Python veresions supported" src="https://img.shields.io/pypi/pyversions/yib"></a>
<a href="https://github.com/mangoumbrella/yib/blob/main/LICENSE"><img alt="License" src="https://img.shields.io/pypi/l/yib.svg"></a>
</p>

## Why yet another utility library?

This library was originally created when I was working on [pyref.dev](https://pyref.dev) and [y2](https://github.com/mangoumbrella/y2) and I want to share some utility functions between the two.

## Changelog

See [CHANGELOG.md](https://github.com/mangoumbrella/yib/blob/main/CHANGELOG.md).

## License

[yib](https://github.com/mangoumbrella/yib) is licensed under the terms of the Apache license. See [LICENSE](https://github.com/mangoumbrella/yib/blob/main/LICENSE) for more information.
